@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010, 2013, 2014  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) 2004-2010, 2013-2015  Internet Systems Consortium, Inc. ("ISC")
  * Copyright (C) 1999-2003  Internet Software Consortium.
  *
  * Permission to use, copy, modify, and/or distribute this software for any
@@ -15,8 +15,6 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: platform.h.in,v 1.56 2010/12/18 01:56:23 each Exp $ */
-
 #ifndef ISC_PLATFORM_H
 #define ISC_PLATFORM_H 1
 
@@ -131,6 +129,11 @@
  */
 #undef ISC_PLATFORM_FIXIN6ISADDR
 
+/*! \brief
+ * Define if the system has struct sockaddr_storage.
+ */
+#define ISC_PLATFORM_HAVESOCKADDRSTORAGE 1
+
 /*! \brief
  * Define if the system supports kqueue multiplexing
  */
@@ -166,6 +169,16 @@
  */
 #undef ISC_PLATFORM_NEEDSPRINTF
 
+/*! \brief
+ * If this system need a modern printf() that format size %z (size_t).
+ */
+#undef ISC_PLATFORM_NEEDPRINTF
+
+/*! \brief
+ * If this system need a modern fprintf() that format size %z (size_t).
+ */
+#undef ISC_PLATFORM_NEEDFPRINTF
+
 /*! \brief
  * The printf format string modifier to use with isc_uint64_t values.
  */
@@ -275,11 +288,17 @@
 #define ISC_PLATFORM_HAVEXADDQ 1
 
 /*
- * If the "atomic swap" operation is available on this architecture,
- * ISC_PLATFORM_HAVEATOMICSTORE" will be defined.
+ * If the 32-bit "atomic swap" operation is available on this
+ * architecture, ISC_PLATFORM_HAVEATOMICSTORE" will be defined.
  */
 #define ISC_PLATFORM_HAVEATOMICSTORE 1
 
+/*
+ * If the 64-bit "atomic swap" operation is available on this
+ * architecture, ISC_PLATFORM_HAVEATOMICSTORE" will be defined.
+ */
+#define ISC_PLATFORM_HAVEATOMICSTOREQ 1
+
 /*
  * If the "compare-and-exchange" operation is available on this architecture,
  * ISC_PLATFORM_HAVECMPXCHG will be defined.
@@ -299,7 +318,7 @@
 /*
  * Define if the standard __asm function must be used.
  */
-
+#undef ISC_PLATFORM_USESTDASM
 
 /*
  * Define if the platform has <strings.h>.
@@ -335,7 +354,7 @@
  * Define if MacOS style of PPC assembly must be used.
  * e.g. "r6", not "6", for register six.
  */
-
+#undef ISC_PLATFORM_USEMACASM
 
 #ifndef ISC_PLATFORM_USEDECLSPEC
 #define LIBISC_EXTERNAL_DATA
